pub fn _mm_extract_si64(x: __m128i, y: __m128i) -> __m128iAvailable on x86-64 and target feature
sse4a and (x86 or x86-64) only.Expand description
Extracts the bit range specified by y from the lower 64 bits of x.
The [13:8] bits of y specify the index of the bit-range to extract. The
[5:0] bits of y specify the length of the bit-range to extract. All
other bits are ignored.
If the length is zero, it is interpreted as 64. If the length and index
are zero, the lower 64 bits of x are extracted.
If length == 0 && index > 0 or length + index > 64 the result is
undefined.
The extracted bits are saved in the least-significant bit positions of the lower quadword of the destination; the remaining bits in the lower quadword of the destination register are cleared to 0. The upper quadword of the destination register is undefined.